@@ -315,12 +315,6 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldl:17th_worcester",
                 1,
             ),
-            District(
-                "18th Essex",
-                "lower",
-                "ocd-division/country:us/state:ma/sldl:18th_essex",
-                1,
-            ),
             District(
                 "18th Middlesex",
                 "lower",
@@ -333,6 +327,12 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldl:18th_suffolk",
                 1,
             ),
+            District(
+                "19th Worcester",
+                "lower",
+                "ocd-division/country:us/state:ma/sldl:19th_worcester",
+                1,
+            ),
             District(
                 "18th Worcester",
                 "lower",
@@ -675,12 +675,6 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldl:4th_barnstable",
                 1,
             ),
-            District(
-                "4th Berkshire",
-                "lower",
-                "ocd-division/country:us/state:ma/sldl:4th_berkshire",
-                1,
-            ),
             District(
                 "4th Bristol",
                 "lower",
@@ -933,6 +927,12 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldl:9th_bristol",
                 1,
             ),
+            District(
+                "18th Essex",
+                "lower",
+                "ocd-division/country:us/state:ma/sldl:18th_essex",
+                1,
+            ),
             District(
                 "9th Essex",
                 "lower",
@@ -1008,6 +1008,12 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldu:5th_middlesex",
                 1,
             ),
+            District(
+                "First Plymouth and Norfolk",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:5th_middlesex",
+                1,
+            ),
             District(
                 "First Bristol and Plymouth",
                 "upper",
@@ -1027,9 +1033,9 @@ MA = State(
                 1,
             ),
             District(
-                "First Hampden and Hampshire",
+                "Hampden and Hampshire",
                 "upper",
-                "ocd-division/country:us/state:ma/sldu:1st_hampden_and_hampshire",
+                "ocd-division/country:us/state:ma/sldu:hampden_and_hampshire",
                 1,
             ),
             District(
@@ -1038,30 +1044,12 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldu:1st_middlesex",
                 1,
             ),
-            District(
-                "First Middlesex and Norfolk",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:1st_middlesex_and_norfolk",
-                1,
-            ),
-            District(
-                "First Plymouth and Bristol",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:1st_plymouth_and_bristol",
-                1,
-            ),
             District(
                 "First Suffolk",
                 "upper",
                 "ocd-division/country:us/state:ma/sldu:1st_suffolk",
                 1,
             ),
-            District(
-                "First Suffolk and Middlesex",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:1st_suffolk_and_middlesex",
-                1,
-            ),
             District(
                 "First Worcester",
                 "upper",
@@ -1078,9 +1066,9 @@ MA = State(
                 "Hampden", "upper", "ocd-division/country:us/state:ma/sldu:hampden", 1
             ),
             District(
-                "Berkshire, Hampshire, Franklin and Hampden",
+                "Hampden, Hampshire and Worcester",
                 "upper",
-                "ocd-division/country:us/state:ma/sldu:berkshire_hampshire_franklin_and_hampden",
+                "ocd-division/country:us/state:ma/sldu:hampden_hampshire_and_worcester",
                 1,
             ),
             District(
@@ -1095,18 +1083,6 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldu:middlesex_and_worcester",
                 1,
             ),
-            District(
-                "Norfolk, Bristol and Middlesex",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:norfolk_bristol_and_middlesex",
-                1,
-            ),
-            District(
-                "Norfolk, Bristol and Plymouth",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:norfolk_bristol_and_plymouth",
-                1,
-            ),
             District(
                 "Norfolk and Plymouth",
                 "upper",
@@ -1125,12 +1101,6 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldu:plymouth_and_barnstable",
                 1,
             ),
-            District(
-                "Plymouth and Norfolk",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:plymouth_and_norfolk",
-                1,
-            ),
             District(
                 "Second Bristol and Plymouth",
                 "upper",
@@ -1149,30 +1119,12 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldu:2nd_essex_and_middlesex",
                 1,
             ),
-            District(
-                "Second Hampden and Hampshire",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:2nd_hampden_and_hampshire",
-                1,
-            ),
             District(
                 "Second Middlesex",
                 "upper",
                 "ocd-division/country:us/state:ma/sldu:2nd_middlesex",
                 1,
             ),
-            District(
-                "Second Middlesex and Norfolk",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:2nd_middlesex_and_norfolk",
-                1,
-            ),
-            District(
-                "Second Plymouth and Bristol",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:2nd_plymouth_and_bristol",
-                1,
-            ),
             District(
                 "Second Suffolk",
                 "upper",
@@ -1180,9 +1132,9 @@ MA = State(
                 1,
             ),
             District(
-                "Second Suffolk and Middlesex",
+                "Second Plymouth and Norfolk",
                 "upper",
-                "ocd-division/country:us/state:ma/sldu:2nd_suffolk_and_middlesex",
+                "ocd-division/country:us/state:ma/sldu:2nd_plymouth_and_norfolk",
                 1,
             ),
             District(
@@ -1203,30 +1155,78 @@ MA = State(
                 "ocd-division/country:us/state:ma/sldu:3rd_middlesex",
                 1,
             ),
+            District(
+                "Third Bristol and Plymouth",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:3rd_bristol_and_plymouth",
+                1,
+            ),
+            District(
+                "Third Suffolk",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:3rd_suffolk",
+                1,
+            ),
             District(
                 "Worcester and Middlesex",
                 "upper",
                 "ocd-division/country:us/state:ma/sldu:worcester_and_middlesex",
                 1,
             ),
-            District(
-                "Worcester and Norfolk",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:worcester_and_norfolk",
-                1,
-            ),
-            District(
-                "Worcester, Hampden, Hampshire and Middlesex",
-                "upper",
-                "ocd-division/country:us/state:ma/sldu:worcester_hampden_hampshire_and_middlesex",
-                1,
-            ),
             District(
                 "Hampshire, Franklin and Worcester",
                 "upper",
                 "ocd-division/country:us/state:ma/sldu:hampshire_franklin_and_worcester",
                 1,
             ),
+            District(
+                "Berkshire, Hampden, Franklin and Hampshire",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:berkshire_hampden_franklin_and_hampshire",
+                1,
+            ),
+            District(
+                "Middlesex and Norfolk",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:middlesex_and_norfolk",
+                1,
+            ),
+            District(
+                "Norfolk and Middlesex",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:norfolk_and_middlesex",
+                1,
+            ),
+            District(
+                "Norfolk, Plymouth and Bristol",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:norfolk_plymouth_and_bristol",
+                1,
+            ),
+            District(
+                "Norfolk, Worcester and Middlesex",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:worcester_and_middlesex",
+                1,
+            ),
+            District(
+                "Suffolk and Middlesex",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:suffolk_and_middlesex",
+                1,
+            ),
+            District(
+                "Worcester and Hampden",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:worcester_and_hampden",
+                1,
+            ),
+            District(
+                "Worcester and Hampshire",
+                "upper",
+                "ocd-division/country:us/state:ma/sldu:worcester_and_hampshire",
+                1,
+            ),
         ],
     ),
 )
